==> estateplat-common-1.1.0-20160921.025033-190-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzTdsyq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;

/**
 * Created with IntelliJ IDEA.
 * 土地所有权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:15
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_tdsyq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzTdsyq implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //地籍号
    @XmlElement(name = "djh")
    private String djh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //面积单位
    @XmlElement(name = "mjdw")
    private String mjdw;
    //农用地面积
    @XmlElement(name = "nydmj")
    private Double nydmj;
    //耕地面积
    @XmlElement(name = "gdmj")
    private Double gdmj;
    //林地面积
    @XmlElement(name = "ldmj")
    private Double ldmj;
    //草地面积
    @XmlElement(name = "cdmj")
    private Double cdmj;
    //其它农用地面积
    @XmlElement(name = "qtnydmj")
    private Double qtnydmj;
    //建设用地面积
    @XmlElement(name = "jsydmj")
    private Double jsydmj;
    //未利用地面积
    @XmlElement(name = "wlydmj")
    private Double wlydmj;
    //备注
    @XmlElement(name = "bz")
    private String bz;

    //原业务号
    private String yywh;
    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public Double getNydmj() {
        return nydmj;
    }

    public void setNydmj(Double nydmj) {
        this.nydmj = nydmj;
    }

    public Double getGdmj() {
        return gdmj;
    }

    public void setGdmj(Double gdmj) {
        this.gdmj = gdmj;
    }

    public Double getLdmj() {
        return ldmj;
    }

    public void setLdmj(Double ldmj) {
        this.ldmj = ldmj;
    }

    public Double getCdmj() {
        return cdmj;
    }

    public void setCdmj(Double cdmj) {
        this.cdmj = cdmj;
    }

    public Double getQtnydmj() {
        return qtnydmj;
    }

    public void setQtnydmj(Double qtnydmj) {
        this.qtnydmj = qtnydmj;
    }

    public Double getJsydmj() {
        return jsydmj;
    }

    public void setJsydmj(Double jsydmj) {
        this.jsydmj = jsydmj;
    }

    public Double getWlydmj() {
        return wlydmj;
    }

    public void setWlydmj(Double wlydmj) {
        this.wlydmj = wlydmj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}

==> estateplat-common-1.2.1-20170622.071222-42-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzTdsyq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;

/**
 * Created with IntelliJ IDEA.
 * 土地所有权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:15
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_tdsyq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzTdsyq implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //地籍号
    @XmlElement(name = "djh")
    private String djh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //面积单位
    @XmlElement(name = "mjdw")
    private String mjdw;
    //农用地面积
    @XmlElement(name = "nydmj")
    private Double nydmj;
    //耕地面积
    @XmlElement(name = "gdmj")
    private Double gdmj;
    //林地面积
    @XmlElement(name = "ldmj")
    private Double ldmj;
    //草地面积
    @XmlElement(name = "cdmj")
    private Double cdmj;
    //其它农用地面积
    @XmlElement(name = "qtnydmj")
    private Double qtnydmj;
    //建设用地面积
    @XmlElement(name = "jsydmj")
    private Double jsydmj;
    //未利用地面积
    @XmlElement(name = "wlydmj")
    private Double wlydmj;
    //备注
    @XmlElement(name = "bz")
    private String bz;

    //原业务号
    private String yywh;
    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    //登簿人
    @XmlElement(name = "dbr")
    private String dbr;

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public Double getNydmj() {
        return nydmj;
    }

    public void setNydmj(Double nydmj) {
        this.nydmj = nydmj;
    }

    public Double getGdmj() {
        return gdmj;
    }

    public void setGdmj(Double gdmj) {
        this.gdmj = gdmj;
    }

    public Double getLdmj() {
        return ldmj;
    }

    public void setLdmj(Double ldmj) {
        this.ldmj = ldmj;
    }

    public Double getCdmj() {
        return cdmj;
    }

    public void setCdmj(Double cdmj) {
        this.cdmj = cdmj;
    }

    public Double getQtnydmj() {
        return qtnydmj;
    }

    public void setQtnydmj(Double qtnydmj) {
        this.qtnydmj = qtnydmj;
    }

    public Double getJsydmj() {
        return jsydmj;
    }

    public void setJsydmj(Double jsydmj) {
        this.jsydmj = jsydmj;
    }

    public Double getWlydmj() {
        return wlydmj;
    }

    public void setWlydmj(Double wlydmj) {
        this.wlydmj = wlydmj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}
